@@ -177,17 +177,19 @@ class VariableClUpdateInnerRepList(Variable):
     value = []
 
     def get(self):
-        val = self.Get('cl_update_rep_list')
-        prev_host = self.Get('cl_update_rep_hosting')
-        if prev_host:
+        def gen():
+            val = self.Get('cl_update_rep_list')
+            prev_host = self.Get('cl_update_rep_hosting')
+            if prev_host:
+                for dct in val:
+                    for key, value in dct.items():
+                        if key == prev_host:
+                            yield value, key.lower()
             for dct in val:
                 for key, value in dct.items():
-                    if key == prev_host:
-                        yield value, key
-        for dct in val:
-            for key, value in dct.items():
-                if key != prev_host:
-                    yield value, key
+                    if key != prev_host:
+                        yield value, key.lower()
+        return [x for x in gen()]
 
 
 class VariableClUpdateRepHosting(Variable):
@@ -197,13 +199,16 @@ class VariableClUpdateRepHosting(Variable):
 class VariableClUpdateRepHostingChoice(Variable):
     type = "choice"
     value = ''
+    opt = ["--hosting"]
 
     def init(self):
         self.label = (_("Hosting name"))
         self.help = (_("Hosting to download from"))
 
     def choice(self):
-        return [x[1] for x in self.Get('cl_update_inner_rep_list')] or ["Calculate"]
+        a = [x[1] for x in self.Get('cl_update_inner_rep_list')]
+        b = self.Get('cl_update_inner_rep_list')
+        return [x[1] for x in self.Get('cl_update_inner_rep_list')]
 
 
 class VariableClUpdateLaymanStorage(Variable):
@@ -633,17 +638,17 @@ class VariableClUpdateOtherSet(Variable):
     Обновить остальные оверлеи
     """
     type = "bool"
-    value = ""
+    value = "on"
 
     def get(self):
-        if self.Get('cl_update_inner_other_set'):
+        if self.Get('cl_update_inner_other_set') != 'auto':
             return self.Get('cl_update_inner_other_set')
         return self.value
 
 
 class VariableClUpdateInnerOtherSet(Variable):
-    type = "bool"
-    value = 'on'
+    type = "bool3"
+    value = Variable.Auto
     metavalue = 'ON/OFF'
     opt = ["-o", "--update-other"]
 
